==> huaweicloudsdkmssi-3.1.130-py2.py3-none-any.whl: huaweicloudsdkmssi/v1/model/update_connection_info_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateConnectionInfoRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connect_id': 'str',
        'body': 'ConnectionInfo'
    }

    attribute_map = {
        'connect_id': 'connect_id',
        'body': 'body'
    }

    def __init__(self, connect_id=None, body=None):
        """UpdateConnectionInfoRequest

        The model defined in huaweicloud sdk

        :param connect_id: ID of Connection
        :type connect_id: str
        :param body: Body of the UpdateConnectionInfoRequest
        :type body: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        
        

        self._connect_id = None
        self._body = None
        self.discriminator = None

        self.connect_id = connect_id
        if body is not None:
            self.body = body

    @property
    def connect_id(self):
        """Gets the connect_id of this UpdateConnectionInfoRequest.

        ID of Connection

        :return: The connect_id of this UpdateConnectionInfoRequest.
        :rtype: str
        """
        return self._connect_id

    @connect_id.setter
    def connect_id(self, connect_id):
        """Sets the connect_id of this UpdateConnectionInfoRequest.

        ID of Connection

        :param connect_id: The connect_id of this UpdateConnectionInfoRequest.
        :type connect_id: str
        """
        self._connect_id = connect_id

    @property
    def body(self):
        """Gets the body of this UpdateConnectionInfoRequest.

        :return: The body of this UpdateConnectionInfoRequest.
        :rtype: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateConnectionInfoRequest.

        :param body: The body of this UpdateConnectionInfoRequest.
        :type body: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConnectionInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmssi-3.1.150-py2.py3-none-any.whl: huaweicloudsdkmssi/v1/model/update_connection_info_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateConnectionInfoRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connect_id': 'str',
        'body': 'ConnectionInfo'
    }

    attribute_map = {
        'connect_id': 'connect_id',
        'body': 'body'
    }

    def __init__(self, connect_id=None, body=None):
        r"""UpdateConnectionInfoRequest

        The model defined in huaweicloud sdk

        :param connect_id: ID of Connection
        :type connect_id: str
        :param body: Body of the UpdateConnectionInfoRequest
        :type body: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        
        

        self._connect_id = None
        self._body = None
        self.discriminator = None

        self.connect_id = connect_id
        if body is not None:
            self.body = body

    @property
    def connect_id(self):
        r"""Gets the connect_id of this UpdateConnectionInfoRequest.

        ID of Connection

        :return: The connect_id of this UpdateConnectionInfoRequest.
        :rtype: str
        """
        return self._connect_id

    @connect_id.setter
    def connect_id(self, connect_id):
        r"""Sets the connect_id of this UpdateConnectionInfoRequest.

        ID of Connection

        :param connect_id: The connect_id of this UpdateConnectionInfoRequest.
        :type connect_id: str
        """
        self._connect_id = connect_id

    @property
    def body(self):
        r"""Gets the body of this UpdateConnectionInfoRequest.

        :return: The body of this UpdateConnectionInfoRequest.
        :rtype: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateConnectionInfoRequest.

        :param body: The body of this UpdateConnectionInfoRequest.
        :type body: :class:`huaweicloudsdkmssi.v1.ConnectionInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConnectionInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
